summary refs log tree commit diff
path: root/tests/unittest.py
diff options
context:
space:
mode:
authorTravis Ralston <travisr@matrix.org>2021-12-28 20:31:10 -0700
committerTravis Ralston <travisr@matrix.org>2021-12-28 20:31:10 -0700
commit73d91b5d34f4df5f6a1ff668113d6a844ad65d8d (patch)
tree2ce890b5045ef17c4c71a219aa76053ad1fa62b0 /tests/unittest.py
parentMerge remote-tracking branch 'origin/rei/as_device_masquerading_msc3202' into... (diff)
parentNewsfile (diff)
downloadsynapse-73d91b5d34f4df5f6a1ff668113d6a844ad65d8d.tar.xz
Merge remote-tracking branch 'origin/rei/msc3202_otks_fbks' into anoa/e2e_as_internal_testing github/travis/alt-todev-masq-otk-fbkey travis/alt-todev-masq-otk-fbkey
Diffstat (limited to 'tests/unittest.py')
-rw-r--r--tests/unittest.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/tests/unittest.py b/tests/unittest.py
index 1431848367..0698b3d13a 100644
--- a/tests/unittest.py
+++ b/tests/unittest.py
@@ -620,18 +620,18 @@ class HomeserverTestCase(TestCase):
         self,
         username: str,
         appservice_token: str,
-    ) -> str:
+    ) -> Tuple[str, str]:
         """Register an appservice user as an application service.
         Requires the client-facing registration API be registered.
 
         Args:
             username: the user to be registered by an application service.
-                Should be a full username, i.e. ""@localpart:hostname" as opposed to just "localpart"
+                Should NOT be a full username, i.e. just "localpart" as opposed to "@localpart:hostname"
             appservice_token: the acccess token for that application service.
 
         Raises: if the request to '/register' does not return 200 OK.
 
         Returns: the MXID of the new user.
         """
         channel = self.make_request(
             "POST",
@@ -643,7 +643,7 @@ class HomeserverTestCase(TestCase):
             access_token=appservice_token,
         )
         self.assertEqual(channel.code, 200, channel.json_body)
-        return channel.json_body["user_id"]
+        return channel.json_body["user_id"], channel.json_body["device_id"]
 
     def login(
         self,
@@ -620,18 +620,18 @@ class HomeserverTestCase(TestCase):
         Raises: if the request to '/register' does not return 200 OK.
 
-        Returns: the MXID of the new user.
+        Returns: the MXID of the new user, the device ID of the new user's first device.
         """
         channel = self.make_request(